@@ -24,6 +24,8 @@
 #ifndef CAPI_MOD_H
 #define CAPI_MOD_H
 
+#include <capi20.h>
+
 /* define ulong if not defined */
 #ifndef C_ULONG_DEFINED
 typedef unsigned long ulong;
@@ -71,6 +73,14 @@ int capi_applid2fd(unsigned);
 
 unsigned capi_return_buffer(unsigned applid, unsigned);
 
+void CapiDebug(int nLevel, const char *pnFormat, ...);
+unsigned short get_word( unsigned char **ppnPtr );
+unsigned short get_netword( unsigned char **ppnPtr );
+unsigned char *put_byte( unsigned char **ppnPtr, _cbyte nVal );
+unsigned char *put_word( unsigned char **ppnPtr, _cword nVal );
+unsigned char *put_dword( unsigned char **ppnPtr, _cdword nVal );
+unsigned char *put_netword( unsigned char **ppnPtr, _cword nVal );
+
 #define MODULE_LOADER_VERSION		2
 
 #define MODULE_INIT( NAME, OPS )\
