@@ -527,7 +527,7 @@ static int check_client_access_start(char *name, char *addr)
         if ((line[0] != 'L') || (line[1] != ':')) continue;
 
         /*
-         * Split the current line into seperate fields.
+         * Split the current line into separate fields.
          */
 
         for (list[0] = line, i = 0, p = line; ((*p) && (i < 3)); p++)
@@ -596,7 +596,7 @@ static int check_client_access_login(char *name, char *addr, char *user, char *p
 	while (streamio_gets(line, VBOXD_LEN_ACCESSLINE, accesslist))
 	{
 		/*
-		 * Split the current line into seperate fields.
+		 * Split the current line into separate fields.
 		 */
 
 		if ((line[0] != 'A') || (line[1] != ':')) continue;
@@ -784,7 +784,7 @@ static void srv_header(int argc, char **argv)
 
 	if (chdir(client_spool) != 0)
 	{
-		message("%s Access denied (messagebox unaccessable).\r\n", VBOXD_VAL_ACCESSDENIED);
+		message("%s Access denied (messagebox inaccessible).\r\n", VBOXD_VAL_ACCESSDENIED);
 
 		return;
 	}
@@ -840,7 +840,7 @@ static void srv_message(int argc, char **argv)
 
 	if (chdir(client_spool) != 0)
 	{
-		message("%s Access denied (messagebox unaccessable).\r\n", VBOXD_VAL_ACCESSDENIED);
+		message("%s Access denied (messagebox inaccessible).\r\n", VBOXD_VAL_ACCESSDENIED);
 
 		return;
 	}
@@ -909,7 +909,7 @@ static void srv_list(int argc, char **argv)
 
 	if (chdir(client_spool) != 0)
 	{
-		message("%s Access denied (messagebox unaccessable).\r\n", VBOXD_VAL_ACCESSDENIED);
+		message("%s Access denied (messagebox inaccessible).\r\n", VBOXD_VAL_ACCESSDENIED);
 
 		return;
 	}
@@ -1029,7 +1029,7 @@ static void srv_count(int argc, char **argv)
 
 	if (chdir(client_spool) != 0)
 	{
-		message("%s Access denied (messagebox unaccessable).\r\n", VBOXD_VAL_ACCESSDENIED);
+		message("%s Access denied (messagebox inaccessible).\r\n", VBOXD_VAL_ACCESSDENIED);
 
 		return;
 	}
@@ -1084,7 +1084,7 @@ static void srv_toggle(int argc, char **argv)
 
 	if (chdir(client_spool) != 0)
 	{
-		message("%s Access denied (messagebox unaccessable).\r\n", VBOXD_VAL_ACCESSDENIED);
+		message("%s Access denied (messagebox inaccessible).\r\n", VBOXD_VAL_ACCESSDENIED);
 
 		return;
 	}
@@ -1133,7 +1133,7 @@ static void srv_delete(int argc, char **argv)
 
 	if (chdir(client_spool) != 0)
 	{
-		message("%s Access denied (messagebox unaccessable).\r\n", VBOXD_VAL_ACCESSDENIED);
+		message("%s Access denied (messagebox inaccessible).\r\n", VBOXD_VAL_ACCESSDENIED);
 
 		return;
 	}
